==> com.github.weisj.jsvg.source_1.7.2.jar: com/github/weisj/jsvg/nodes/MetaSVGNode.java <==
/*
 * MIT License
 *
 * Copyright (c) 2021-2023 Jannis Weis
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package com.github.weisj.jsvg.nodes;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import com.github.weisj.jsvg.parser.AttributeNode;

/**
 * Even though elements of this type can have an id, it doesn't provide any benefit as you
 * can't do anything with it (per contract of subclassing this type).
 * <p>
 * Note: Subclasses of this type may accept child nodes. Nonetheless, this isn't a container type
 * as there is no reason to keep meta information for rendering. Any child elements with an "id" will
 * be kept by the loader for resolving during build time and discarded if unused.
 */
public abstract class MetaSVGNode implements SVGNode {

    @Override
    public @Nullable String id() {
        return null;
    }

    @Override
    public void build(@NotNull AttributeNode attributeNode) {}

    @Override
    public void addContent(char[] content) {}
}

==> com.github.weisj.jsvg.source_2.0.0.jar: com/github/weisj/jsvg/nodes/MetaSVGNode.java <==
/*
 * MIT License
 *
 * Copyright (c) 2021-2025 Jannis Weis
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */
package com.github.weisj.jsvg.nodes;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import com.github.weisj.jsvg.parser.impl.AttributeNode;

/**
 * Even though elements of this type can have an id, it doesn't provide any benefit as you
 * can't do anything with it (per contract of subclassing this type).
 * <p>
 * Note: Subclasses of this type may accept child nodes. Nonetheless, this isn't a container type
 * as there is no reason to keep meta information for rendering. Any child elements with an "id" will
 * be kept by the loader for resolving during build time and discarded if unused.
 */
public abstract class MetaSVGNode implements SVGNode {

    @Override
    public @Nullable String id() {
        return null;
    }

    @Override
    public void build(@NotNull AttributeNode attributeNode) {}

    @Override
    public void addContent(char[] content) {}
}
